# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: qbit.proto
# Protobuf Python Version: 6.30.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    0,
    '',
    'qbit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nqbit.proto\x12\x03qrl\x1a\x1cgoogle/api/annotations.proto\"\x07\n\x05\x45mpty\"\x11\n\x0fGetNodeStateReq\"/\n\x10GetNodeStateResp\x12\x1b\n\x04info\x18\x01 \x01(\x0b\x32\r.qrl.NodeInfo\"\x12\n\x10GetKnownPeersReq\"U\n\x11GetKnownPeersResp\x12 \n\tnode_info\x18\x01 \x01(\x0b\x32\r.qrl.NodeInfo\x12\x1e\n\x0bknown_peers\x18\x02 \x03(\x0b\x32\t.qrl.Peer\"\x11\n\x0fGetPeersStatReq\"5\n\x10GetPeersStatResp\x12!\n\npeers_stat\x18\x01 \x03(\x0b\x32\r.qrl.PeerStat\"\x12\n\x10GetChainStatsReq\"U\n\x11GetChainStatsResp\x12\x12\n\nstate_size\x18\x01 \x01(\x04\x12\x15\n\rstate_size_mb\x18\x02 \x01(\t\x12\x15\n\rstate_size_gb\x18\x03 \x01(\t\"\x14\n\x12GetStakingStatsReq\"\xe1\x01\n\x13GetStakingStatsResp\x12\x15\n\rtotal_stakers\x18\x01 \x01(\r\x12\x16\n\x0e\x61\x63tive_stakers\x18\x02 \x01(\r\x12\x1b\n\x13total_staked_amount\x18\x03 \x01(\x04\x12\x17\n\x0fstaking_enabled\x18\x04 \x01(\x08\x12\x1b\n\x13\x64onor_wallet_loaded\x18\x05 \x01(\x08\x12\x18\n\x10min_stake_amount\x18\x06 \x01(\x04\x12\x17\n\x0freward_interval\x18\x07 \x01(\r\x12\x15\n\rreward_amount\x18\x08 \x01(\x04\"\x12\n\x10GetStakerListReq\"P\n\nStakerInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\r\n\x05nonce\x18\x04 \x01(\x04\"`\n\x11GetStakerListResp\x12 \n\x07stakers\x18\x01 \x03(\x0b\x32\x0f.qrl.StakerInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x14\n\x0ctotal_staked\x18\x03 \x01(\x04\")\n\x0bGetStatsReq\x12\x1a\n\x12include_timeseries\x18\x01 \x01(\x08\"\x84\x02\n\x0cGetStatsResp\x12 \n\tnode_info\x18\x01 \x01(\x0b\x32\r.qrl.NodeInfo\x12\r\n\x05\x65poch\x18\x02 \x01(\x04\x12\x16\n\x0euptime_network\x18\x03 \x01(\x04\x12\x19\n\x11\x62lock_last_reward\x18\x04 \x01(\x04\x12\x17\n\x0f\x62lock_time_mean\x18\x05 \x01(\x04\x12\x15\n\rblock_time_sd\x18\x06 \x01(\x04\x12\x1a\n\x12\x63oins_total_supply\x18\x07 \x01(\x04\x12\x15\n\rcoins_emitted\x18\x08 \x01(\x04\x12-\n\x10\x62lock_timeseries\x18\t \x03(\x0b\x32\x13.qrl.BlockDataPoint\"!\n\x13GetAddressFromPKReq\x12\n\n\x02pk\x18\x01 \x01(\x0c\"\'\n\x14GetAddressFromPKResp\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"\xb2\x01\n\x0e\x42lockDataPoint\x12\x0e\n\x06number\x18\x01 \x01(\x04\x12\x12\n\ndifficulty\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x11\n\ttime_last\x18\x04 \x01(\x04\x12\x13\n\x0btime_movavg\x18\x05 \x01(\x04\x12\x12\n\nhash_power\x18\x06 \x01(\x02\x12\x13\n\x0bheader_hash\x18\x07 \x01(\x0c\x12\x18\n\x10header_hash_prev\x18\x08 \x01(\x0c\"g\n\x12GetAddressStateReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x1c\n\x14\x65xclude_ots_bitfield\x18\x02 \x01(\x08\x12\"\n\x1a\x65xclude_transaction_hashes\x18\x03 \x01(\x08\"7\n\x13GetAddressStateResp\x12 \n\x05state\x18\x01 \x01(\x0b\x32\x11.qrl.AddressState\"I\n\x1cGetOptimizedAddressStateResp\x12)\n\x05state\x18\x01 \x01(\x0b\x32\x1a.qrl.OptimizedAddressState\"-\n\x1aGetMultiSigAddressStateReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"G\n\x1bGetMultiSigAddressStateResp\x12(\n\x05state\x18\x01 \x01(\x0b\x32\x19.qrl.MultiSigAddressState\"6\n\nIsSlaveReq\x12\x16\n\x0emaster_address\x18\x01 \x01(\x0c\x12\x10\n\x08slave_pk\x18\x02 \x01(\x0c\"\x1d\n\x0bIsSlaveResp\x12\x0e\n\x06result\x18\x01 \x01(\x08\"\"\n\x0fParseAddressReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"J\n\x10ParseAddressResp\x12\x10\n\x08is_valid\x18\x01 \x01(\x08\x12$\n\x04\x64\x65sc\x18\x02 \x01(\x0b\x32\x16.qrl.AddressDescriptor\"\x1d\n\x0cGetObjectReq\x12\r\n\x05query\x18\x01 \x01(\x0c\"\xbc\x01\n\rGetObjectResp\x12\r\n\x05\x66ound\x18\x01 \x01(\x08\x12\x33\n\raddress_state\x18\x02 \x01(\x0b\x32\x1a.qrl.OptimizedAddressStateH\x00\x12/\n\x0btransaction\x18\x03 \x01(\x0b\x32\x18.qrl.TransactionExtendedH\x00\x12,\n\x0e\x62lock_extended\x18\x04 \x01(\x0b\x32\x12.qrl.BlockExtendedH\x00\x42\x08\n\x06result\"\xb7\x01\n\x10GetLatestDataReq\x12,\n\x06\x66ilter\x18\x01 \x01(\x0e\x32\x1c.qrl.GetLatestDataReq.Filter\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x10\n\x08quantity\x18\x03 \x01(\r\"S\n\x06\x46ilter\x12\x07\n\x03\x41LL\x10\x00\x12\x10\n\x0c\x42LOCKHEADERS\x10\x01\x12\x10\n\x0cTRANSACTIONS\x10\x02\x12\x1c\n\x18TRANSACTIONS_UNCONFIRMED\x10\x03\"\xaf\x01\n\x11GetLatestDataResp\x12.\n\x0c\x62lockheaders\x18\x01 \x03(\x0b\x32\x18.qrl.BlockHeaderExtended\x12.\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x18.qrl.TransactionExtended\x12:\n\x18transactions_unconfirmed\x18\x03 \x03(\x0b\x32\x18.qrl.TransactionExtended\"\x82\x01\n\x10TransferCoinsReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x14\n\x0c\x61\x64\x64resses_to\x18\x02 \x03(\x0c\x12\x0f\n\x07\x61mounts\x18\x03 \x03(\x04\x12\x14\n\x0cmessage_data\x18\x04 \x01(\x0c\x12\x0b\n\x03\x66\x65\x65\x18\x05 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x06 \x01(\x0c\"T\n\x11TransferCoinsResp\x12?\n\x1d\x65xtended_transaction_unsigned\x18\x01 \x01(\x0b\x32\x18.qrl.TransactionExtended\"B\n\x12PushTransactionReq\x12,\n\x12transaction_signed\x18\x01 \x01(\x0b\x32\x10.qrl.Transaction\"\xca\x01\n\x13PushTransactionResp\x12\x39\n\nerror_code\x18\x01 \x01(\x0e\x32%.qrl.PushTransactionResp.ResponseCode\x12\x19\n\x11\x65rror_description\x18\x02 \x01(\t\x12\x0f\n\x07tx_hash\x18\x03 \x01(\x0c\"L\n\x0cResponseCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x15\n\x11VALIDATION_FAILED\x10\x02\x12\r\n\tSUBMITTED\x10\x03\"\x82\x01\n\x14MultiSigCreateTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x13\n\x0bsignatories\x18\x02 \x03(\x0c\x12\x0f\n\x07weights\x18\x03 \x03(\r\x12\x11\n\tthreshold\x18\x04 \x01(\r\x12\x0b\n\x03\x66\x65\x65\x18\x05 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x06 \x01(\x0c\"\xa3\x01\n\x13MultiSigSpendTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x19\n\x11multi_sig_address\x18\x02 \x01(\x0c\x12\x10\n\x08\x61\x64\x64rs_to\x18\x03 \x03(\x0c\x12\x0f\n\x07\x61mounts\x18\x04 \x03(\x04\x12\x1b\n\x13\x65xpiry_block_number\x18\x05 \x01(\x04\x12\x0b\n\x03\x66\x65\x65\x18\x06 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x07 \x01(\x0c\"k\n\x12MultiSigVoteTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x12\n\nshared_key\x18\x02 \x01(\x0c\x12\x0e\n\x06unvote\x18\x03 \x01(\x08\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x05 \x01(\x0c\"d\n\rMessageTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x12\x0f\n\x07\x61\x64\x64r_to\x18\x03 \x01(\x0c\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x05 \x01(\x0c\"\xad\x01\n\x0bTokenTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x0e\n\x06symbol\x18\x02 \x01(\x0c\x12\x0c\n\x04name\x18\x03 \x01(\x0c\x12\r\n\x05owner\x18\x04 \x01(\x0c\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x04\x12,\n\x10initial_balances\x18\x06 \x03(\x0b\x32\x12.qrl.AddressAmount\x12\x0b\n\x03\x66\x65\x65\x18\x07 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x08 \x01(\x0c\"\x85\x01\n\x13TransferTokenTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x14\n\x0c\x61\x64\x64resses_to\x18\x02 \x03(\x0c\x12\x14\n\x0ctoken_txhash\x18\x03 \x01(\x0c\x12\x0f\n\x07\x61mounts\x18\x04 \x03(\x04\x12\x0b\n\x03\x66\x65\x65\x18\x05 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x06 \x01(\x0c\"i\n\x0bSlaveTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x11\n\tslave_pks\x18\x02 \x03(\x0c\x12\x14\n\x0c\x61\x63\x63\x65ss_types\x18\x03 \x03(\r\x12\x0b\n\x03\x66\x65\x65\x18\x04 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x05 \x01(\x0c\"i\n\rLatticeTxnReq\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x0b\n\x03pk1\x18\x02 \x01(\x0c\x12\x0b\n\x03pk2\x18\x03 \x01(\x0c\x12\x0b\n\x03pk3\x18\x04 \x01(\x0c\x12\x0b\n\x03\x66\x65\x65\x18\x05 \x01(\x04\x12\x0f\n\x07xmss_pk\x18\x06 \x01(\x0c\"H\n\x0fMiniTransaction\x12\x18\n\x10transaction_hash\x18\x01 \x01(\t\x12\x0b\n\x03out\x18\x02 \x01(\x08\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04\"$\n\x11GetTransactionReq\x12\x0f\n\x07tx_hash\x18\x01 \x01(\x0c\"\xa0\x01\n\x12GetTransactionResp\x12\x1c\n\x02tx\x18\x01 \x01(\x0b\x32\x10.qrl.Transaction\x12\x15\n\rconfirmations\x18\x02 \x01(\x04\x12\x14\n\x0c\x62lock_number\x18\x03 \x01(\x04\x12\x19\n\x11\x62lock_header_hash\x18\x04 \x01(\x0c\x12\x11\n\ttimestamp\x18\x05 \x01(\x04\x12\x11\n\taddr_from\x18\x06 \x01(\x0c\"^\n\x1fGetMiniTransactionsByAddressReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x15\n\ritem_per_page\x18\x02 \x01(\x04\x12\x13\n\x0bpage_number\x18\x03 \x01(\x04\"d\n GetMiniTransactionsByAddressResp\x12/\n\x11mini_transactions\x18\x01 \x03(\x0b\x32\x14.qrl.MiniTransaction\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\"Z\n\x1bGetTransactionsByAddressReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x15\n\ritem_per_page\x18\x02 \x01(\x04\x12\x13\n\x0bpage_number\x18\x03 \x01(\x04\"T\n\x1cGetTransactionsByAddressResp\x12\x34\n\x13transactions_detail\x18\x01 \x03(\x0b\x32\x17.qrl.GetTransactionResp\"\xb8\x02\n\x1fGetMultiSigSpendTxsByAddressReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x15\n\ritem_per_page\x18\x02 \x01(\x04\x12\x13\n\x0bpage_number\x18\x03 \x01(\x04\x12\x44\n\x0b\x66ilter_type\x18\x04 \x01(\x0e\x32/.qrl.GetMultiSigSpendTxsByAddressReq.FilterType\"\x91\x01\n\nFilterType\x12\x08\n\x04NONE\x10\x00\x12\x11\n\rEXECUTED_ONLY\x10\x01\x12\x10\n\x0cNON_EXECUTED\x10\x02\x12\x0b\n\x07\x45XPIRED\x10\x03\x12\x0f\n\x0bNON_EXPIRED\x10\x04\x12\x18\n\x14NON_EXECUTED_EXPIRED\x10\x05\x12\x1c\n\x18NON_EXECUTED_NON_EXPIRED\x10\x06\"X\n GetMultiSigSpendTxsByAddressResp\x12\x34\n\x13transactions_detail\x18\x01 \x03(\x0b\x32\x17.qrl.GetTransactionResp\"2\n\x0fGetVoteStatsReq\x12\x1f\n\x17multi_sig_spend_tx_hash\x18\x01 \x01(\x0c\"6\n\x10GetVoteStatsResp\x12\"\n\nvote_stats\x18\x01 \x01(\x0b\x32\x0e.qrl.VoteStats\"U\n\x1dGetInboxMessagesByAddressResp\x12\x34\n\x13transactions_detail\x18\x01 \x03(\x0b\x32\x17.qrl.GetTransactionResp\"l\n\x0cInboxMessage\x12\x11\n\taddr_from\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x0f\n\x07message\x18\x03 \x01(\x0c\x12\x0f\n\x07tx_hash\x18\x04 \x01(\x0c\x12\x14\n\x0c\x62lock_number\x18\x05 \x01(\x04\"R\n\x0bTokenDetail\x12\x14\n\x0ctoken_txhash\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\x0c\x12\x0e\n\x06symbol\x18\x03 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x04 \x01(\x04\"A\n\x16GetTokensByAddressResp\x12\'\n\rtokens_detail\x18\x01 \x03(\x0b\x32\x10.qrl.TokenDetail\"9\n\x0bSlaveDetail\x12\x15\n\rslave_address\x18\x01 \x01(\x0c\x12\x13\n\x0b\x61\x63\x63\x65ss_type\x18\x02 \x01(\x04\"A\n\x16GetSlavesByAddressResp\x12\'\n\rslaves_detail\x18\x01 \x03(\x0b\x32\x10.qrl.SlaveDetail\"J\n\x10LatticePKsDetail\x12\x0b\n\x03pk1\x18\x01 \x01(\x0c\x12\x0b\n\x03pk2\x18\x02 \x01(\x0c\x12\x0b\n\x03pk3\x18\x03 \x01(\x0c\x12\x0f\n\x07tx_hash\x18\x04 \x01(\x0c\"O\n\x1aGetLatticePKsByAddressResp\x12\x31\n\x12lattice_pks_detail\x18\x01 \x03(\x0b\x32\x15.qrl.LatticePKsDetail\"2\n\x0eMultiSigDetail\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\"R\n!GetMultiSigAddressesByAddressResp\x12-\n\x10multi_sig_detail\x18\x01 \x03(\x0b\x32\x13.qrl.MultiSigDetail\" \n\rGetBalanceReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\"!\n\x0eGetBalanceResp\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\"\'\n\x12GetTotalBalanceReq\x12\x11\n\taddresses\x18\x01 \x03(\x0c\"&\n\x13GetTotalBalanceResp\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\"b\n\tGetOTSReq\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x11\n\tpage_from\x18\x02 \x01(\x04\x12\x12\n\npage_count\x18\x03 \x01(\x04\x12\x1d\n\x15unused_ots_index_from\x18\x04 \x01(\x04\">\n\x11OTSBitfieldByPage\x12\x14\n\x0cots_bitfield\x18\x01 \x03(\x0c\x12\x13\n\x0bpage_number\x18\x02 \x01(\x04\"\x81\x01\n\nGetOTSResp\x12\x34\n\x14ots_bitfield_by_page\x18\x01 \x03(\x0b\x32\x16.qrl.OTSBitfieldByPage\x12\x1d\n\x15next_unused_ots_index\x18\x02 \x01(\x04\x12\x1e\n\x16unused_ots_index_found\x18\x03 \x01(\x08\"\x0e\n\x0cGetHeightReq\"\x1f\n\rGetHeightResp\x12\x0e\n\x06height\x18\x01 \x01(\x04\"\"\n\x0bGetBlockReq\x12\x13\n\x0bheader_hash\x18\x01 \x01(\x0c\")\n\x0cGetBlockResp\x12\x19\n\x05\x62lock\x18\x01 \x01(\x0b\x32\n.qrl.Block\"+\n\x13GetBlockByNumberReq\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\"1\n\x14GetBlockByNumberResp\x12\x19\n\x05\x62lock\x18\x01 \x01(\x0b\x32\n.qrl.Block\"\x16\n\x14GetLocalAddressesReq\"*\n\x15GetLocalAddressesResp\x12\x11\n\taddresses\x18\x01 \x03(\x0c\"\x8d\x02\n\x08NodeInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\"\n\x05state\x18\x02 \x01(\x0e\x32\x13.qrl.NodeInfo.State\x12\x17\n\x0fnum_connections\x18\x03 \x01(\r\x12\x17\n\x0fnum_known_peers\x18\x04 \x01(\r\x12\x0e\n\x06uptime\x18\x05 \x01(\x04\x12\x14\n\x0c\x62lock_height\x18\x06 \x01(\x04\x12\x17\n\x0f\x62lock_last_hash\x18\x07 \x01(\x0c\x12\x12\n\nnetwork_id\x18\x08 \x01(\t\"G\n\x05State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08UNSYNCED\x10\x01\x12\x0b\n\x07SYNCING\x10\x02\x12\n\n\x06SYNCED\x10\x03\x12\n\n\x06\x46ORKED\x10\x04\"\x85\x01\n\x11\x41\x64\x64ressDescriptor\x12\x15\n\rhash_function\x18\x01 \x01(\t\x12\x18\n\x10signature_scheme\x18\x02 \x01(\t\x12\x13\n\x0btree_height\x18\x03 \x01(\r\x12\x12\n\nsignatures\x18\x04 \x01(\r\x12\x16\n\x0e\x61\x64\x64ress_format\x18\x05 \x01(\t\"\'\n\x0bStoredPeers\x12\x18\n\x05peers\x18\x01 \x03(\x0b\x32\t.qrl.Peer\"\x12\n\x04Peer\x12\n\n\x02ip\x18\x01 \x01(\t\"\xfe\x02\n\x0c\x41\x64\x64ressState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\x12\r\n\x05nonce\x18\x03 \x01(\x04\x12\x1a\n\x12transaction_hashes\x18\x05 \x03(\x0c\x12-\n\x06tokens\x18\x06 \x03(\x0b\x32\x1d.qrl.AddressState.TokensEntry\x12&\n\x0elatticePK_list\x18\x07 \x03(\x0b\x32\x0e.qrl.LatticePK\x12H\n\x15slave_pks_access_type\x18\x08 \x03(\x0b\x32).qrl.AddressState.SlavePksAccessTypeEntry\x12\x16\n\x0e\x66\x61lcon_pk_list\x18\n \x03(\x0c\x1a-\n\x0bTokensEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x39\n\x17SlavePksAccessTypeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\xdb\x03\n\x15OptimizedAddressState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\x12\r\n\x05nonce\x18\x03 \x01(\x04\x12\x1c\n\x14used_falcon_pk_count\x18\x05 \x01(\x04\x12\x1e\n\x16transaction_hash_count\x18\x06 \x01(\x04\x12\x14\n\x0ctokens_count\x18\x07 \x01(\x04\x12\x14\n\x0cslaves_count\x18\x08 \x01(\x04\x12\x18\n\x10lattice_pk_count\x18\t \x01(\x04\x12\x1f\n\x17multi_sig_address_count\x18\n \x01(\x04\x12\x1d\n\x15multi_sig_spend_count\x18\x0b \x01(\x04\x12\x1b\n\x13inbox_message_count\x18\x0c \x01(\x04\x12\x17\n\x0f\x66\x61lcon_pk_count\x18\r \x01(\x04\x12+\n#foundation_multi_sig_spend_txn_hash\x18\x11 \x03(\x0c\x12*\n\"foundation_multi_sig_vote_txn_hash\x18\x12 \x03(\x0c\x12\x0f\n\x07unvotes\x18\x13 \x03(\x0c\x12-\n\x13proposal_vote_stats\x18\x14 \x03(\x0b\x32\x10.qrl.Transaction\"\x93\x03\n\x14MultiSigAddressState\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x18\n\x10\x63reation_tx_hash\x18\x02 \x01(\x0c\x12\r\n\x05nonce\x18\x03 \x01(\x04\x12\x0f\n\x07\x62\x61lance\x18\x04 \x01(\x04\x12\x13\n\x0bsignatories\x18\x05 \x03(\x0c\x12\x0f\n\x07weights\x18\x06 \x03(\r\x12\x11\n\tthreshold\x18\x07 \x01(\r\x12\x1e\n\x16transaction_hash_count\x18\x08 \x01(\x04\x12\x1d\n\x15multi_sig_spend_count\x18\t \x01(\x04\x12\x1f\n\x17multi_sig_address_count\x18\n \x01(\x04\x12+\n#foundation_multi_sig_spend_txn_hash\x18\x0b \x03(\x0c\x12*\n\"foundation_multi_sig_vote_txn_hash\x18\x0c \x03(\x0c\x12\x0f\n\x07unvotes\x18\r \x03(\x0c\x12-\n\x13proposal_vote_stats\x18\x0e \x03(\x0b\x32\x10.qrl.Transaction\"\'\n\x15MultiSigAddressesList\x12\x0e\n\x06hashes\x18\x01 \x03(\x0c\"\x1a\n\x08\x44\x61taList\x12\x0e\n\x06values\x18\x01 \x03(\x0c\"\x1d\n\x08\x42itfield\x12\x11\n\tbitfields\x18\x01 \x03(\x0c\"%\n\x13TransactionHashList\x12\x0e\n\x06hashes\x18\x01 \x03(\x0c\"3\n\tLatticePK\x12\x10\n\x08kyber_pk\x18\x01 \x01(\x0c\x12\x14\n\x0c\x64ilithium_pk\x18\x02 \x01(\x0c\"0\n\rAddressAmount\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04\"\xd7\x01\n\x0b\x42lockHeader\x12\x13\n\x0bhash_header\x18\x01 \x01(\x0c\x12\x14\n\x0c\x62lock_number\x18\x02 \x01(\x04\x12\x19\n\x11timestamp_seconds\x18\x03 \x01(\x04\x12\x18\n\x10hash_header_prev\x18\x04 \x01(\x0c\x12\x14\n\x0creward_block\x18\x05 \x01(\x04\x12\x12\n\nreward_fee\x18\x06 \x01(\x04\x12\x13\n\x0bmerkle_root\x18\x07 \x01(\x0c\x12\x14\n\x0cmining_nonce\x18\x08 \x01(\r\x12\x13\n\x0b\x65xtra_nonce\x18\t \x01(\x04\"i\n\x13\x42lockHeaderExtended\x12 \n\x06header\x18\x01 \x01(\x0b\x32\x10.qrl.BlockHeader\x12\x30\n\x11transaction_count\x18\x02 \x01(\x0b\x32\x15.qrl.TransactionCount\"q\n\x10TransactionCount\x12/\n\x05\x63ount\x18\x01 \x03(\x0b\x32 .qrl.TransactionCount.CountEntry\x1a,\n\nCountEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\x91\x01\n\x13TransactionExtended\x12 \n\x06header\x18\x01 \x01(\x0b\x32\x10.qrl.BlockHeader\x12\x1c\n\x02tx\x18\x02 \x01(\x0b\x32\x10.qrl.Transaction\x12\x11\n\taddr_from\x18\x03 \x01(\x0c\x12\x0c\n\x04size\x18\x04 \x01(\x04\x12\x19\n\x11timestamp_seconds\x18\x05 \x01(\x04\"\xa6\x01\n\rBlockExtended\x12 \n\x06header\x18\x01 \x01(\x0b\x32\x10.qrl.BlockHeader\x12\x37\n\x15\x65xtended_transactions\x18\x02 \x03(\x0b\x32\x18.qrl.TransactionExtended\x12,\n\x0fgenesis_balance\x18\x03 \x03(\x0b\x32\x13.qrl.GenesisBalance\x12\x0c\n\x04size\x18\x04 \x01(\x04\"\x7f\n\x05\x42lock\x12 \n\x06header\x18\x01 \x01(\x0b\x32\x10.qrl.BlockHeader\x12&\n\x0ctransactions\x18\x02 \x03(\x0b\x32\x10.qrl.Transaction\x12,\n\x0fgenesis_balance\x18\x03 \x03(\x0b\x32\x13.qrl.GenesisBalance\"2\n\x0eGenesisBalance\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x04\"D\n\x11\x42lockMetaDataList\x12/\n\x13\x62lock_number_hashes\x18\x01 \x03(\x0b\x32\x12.qrl.BlockMetaData\"\xaa\x15\n\x0bTransaction\x12\x13\n\x0bmaster_addr\x18\x01 \x01(\x0c\x12\x0b\n\x03\x66\x65\x65\x18\x02 \x01(\x04\x12\x12\n\npublic_key\x18\x03 \x01(\x0c\x12\x11\n\tsignature\x18\x04 \x01(\x0c\x12\r\n\x05nonce\x18\x05 \x01(\x04\x12\x18\n\x10transaction_hash\x18\x06 \x01(\x0c\x12-\n\x08transfer\x18\x07 \x01(\x0b\x32\x19.qrl.Transaction.TransferH\x00\x12-\n\x08\x63oinbase\x18\x08 \x01(\x0b\x32\x19.qrl.Transaction.CoinBaseH\x00\x12\x36\n\tlatticePK\x18\t \x01(\x0b\x32!.qrl.Transaction.LatticePublicKeyH\x00\x12+\n\x07message\x18\n \x01(\x0b\x32\x18.qrl.Transaction.MessageH\x00\x12\'\n\x05token\x18\x0b \x01(\x0b\x32\x16.qrl.Transaction.TokenH\x00\x12\x38\n\x0etransfer_token\x18\x0c \x01(\x0b\x32\x1e.qrl.Transaction.TransferTokenH\x00\x12\'\n\x05slave\x18\r \x01(\x0b\x32\x16.qrl.Transaction.SlaveH\x00\x12;\n\x10multi_sig_create\x18\x0e \x01(\x0b\x32\x1f.qrl.Transaction.MultiSigCreateH\x00\x12\x39\n\x0fmulti_sig_spend\x18\x0f \x01(\x0b\x32\x1e.qrl.Transaction.MultiSigSpendH\x00\x12\x37\n\x0emulti_sig_vote\x18\x10 \x01(\x0b\x32\x1d.qrl.Transaction.MultiSigVoteH\x00\x12:\n\x0fproposal_create\x18\x11 \x01(\x0b\x32\x1f.qrl.Transaction.ProposalCreateH\x00\x12\x36\n\rproposal_vote\x18\x12 \x01(\x0b\x32\x1d.qrl.Transaction.ProposalVoteH\x00\x1a\x43\n\x08Transfer\x12\x10\n\x08\x61\x64\x64rs_to\x18\x01 \x03(\x0c\x12\x0f\n\x07\x61mounts\x18\x02 \x03(\x04\x12\x14\n\x0cmessage_data\x18\x03 \x01(\x0c\x1a+\n\x08\x43oinBase\x12\x0f\n\x07\x61\x64\x64r_to\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04\x1a\x39\n\x10LatticePublicKey\x12\x0b\n\x03pk1\x18\x01 \x01(\x0c\x12\x0b\n\x03pk2\x18\x02 \x01(\x0c\x12\x0b\n\x03pk3\x18\x03 \x01(\x0c\x1a\x30\n\x07Message\x12\x14\n\x0cmessage_hash\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61\x64\x64r_to\x18\x02 \x01(\x0c\x1at\n\x05Token\x12\x0e\n\x06symbol\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\x0c\x12\r\n\x05owner\x18\x03 \x01(\x0c\x12\x10\n\x08\x64\x65\x63imals\x18\x04 \x01(\x04\x12,\n\x10initial_balances\x18\x05 \x03(\x0b\x32\x12.qrl.AddressAmount\x1aH\n\rTransferToken\x12\x14\n\x0ctoken_txhash\x18\x01 \x01(\x0c\x12\x10\n\x08\x61\x64\x64rs_to\x18\x02 \x03(\x0c\x12\x0f\n\x07\x61mounts\x18\x03 \x03(\x04\x1a\x30\n\x05Slave\x12\x11\n\tslave_pks\x18\x01 \x03(\x0c\x12\x14\n\x0c\x61\x63\x63\x65ss_types\x18\x02 \x03(\r\x1aI\n\x0eMultiSigCreate\x12\x13\n\x0bsignatories\x18\x01 \x03(\x0c\x12\x0f\n\x07weights\x18\x02 \x03(\r\x12\x11\n\tthreshold\x18\x03 \x01(\r\x1aj\n\rMultiSigSpend\x12\x19\n\x11multi_sig_address\x18\x01 \x01(\x0c\x12\x10\n\x08\x61\x64\x64rs_to\x18\x02 \x03(\x0c\x12\x0f\n\x07\x61mounts\x18\x03 \x03(\x04\x12\x1b\n\x13\x65xpiry_block_number\x18\x04 \x01(\x04\x1aH\n\x0cMultiSigVote\x12\x12\n\nshared_key\x18\x01 \x01(\x0c\x12\x0e\n\x06unvote\x18\x02 \x01(\x08\x12\x14\n\x0cprev_tx_hash\x18\x03 \x01(\x0c\x1a\x9b\t\n\x0eProposalCreate\x12\x1b\n\x13\x65xpiry_block_number\x18\x01 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x32\n\x03qip\x18\x03 \x01(\x0b\x32#.qrl.Transaction.ProposalCreate.QIPH\x00\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32&.qrl.Transaction.ProposalCreate.ConfigH\x00\x12\x36\n\x05other\x18\x05 \x01(\x0b\x32%.qrl.Transaction.ProposalCreate.OtherH\x00\x1a\x17\n\x03QIP\x12\x10\n\x08qip_link\x18\x01 \x01(\t\x1a\xed\x06\n\x06\x43onfig\x12\x18\n\x10\x63hanges_bitfield\x18\x01 \x03(\x0c\x12\x13\n\x0breorg_limit\x18\x02 \x01(\x04\x12\x17\n\x0fmax_coin_supply\x18\x03 \x01(\x04\x12,\n$complete_emission_time_span_in_years\x18\x04 \x01(\x04\x12\x1b\n\x13mining_nonce_offset\x18\x05 \x01(\x04\x12\x1a\n\x12\x65xtra_nonce_offset\x18\x06 \x01(\x04\x12!\n\x19mining_blob_size_in_bytes\x18\x07 \x01(\x04\x12\x1f\n\x17\x62lock_timing_in_seconds\x18\x08 \x01(\x04\x12 \n\x18number_of_blocks_analyze\x18\t \x01(\x04\x12\x1d\n\x15\x62lock_size_multiplier\x18\n \x01(\x04\x12%\n\x1d\x62lock_min_size_limit_in_bytes\x18\x0b \x01(\x04\x12&\n\x1etransaction_multi_output_limit\x18\x0c \x01(\x04\x12\x1a\n\x12message_max_length\x18\r \x01(\x04\x12\x1f\n\x17token_symbol_max_length\x18\x0e \x01(\x04\x12\x1d\n\x15token_name_max_length\x18\x0f \x01(\x04\x12\x1e\n\x16lattice_pk1_max_length\x18\x10 \x01(\x04\x12\x1e\n\x16lattice_pk2_max_length\x18\x11 \x01(\x04\x12\x1e\n\x16lattice_pk3_max_length\x18\x12 \x01(\x04\x12\x39\n1foundation_multi_sig_address_threshold_percentage\x18\x13 \x01(\x04\x12\x1e\n\x16proposal_threshold_per\x18\x14 \x01(\x04\x12 \n\x18proposal_default_options\x18\x15 \x03(\t\x12\x1e\n\x16\x64\x65scription_max_length\x18\x16 \x01(\x04\x12\x1a\n\x12options_max_number\x18\x17 \x01(\x04\x12\x1e\n\x16option_max_text_length\x18\x18 \x01(\x04\x12(\n proposal_config_activation_delay\x18\x19 \x01(\x04\x12\x15\n\rN_measurement\x18\x1a \x01(\x04\x12\n\n\x02kp\x18\x1b \x01(\x04\x1a\x18\n\x05Other\x12\x0f\n\x07options\x18\x01 \x03(\tB\x0e\n\x0cproposalType\x1a\x32\n\x0cProposalVote\x12\x12\n\nshared_key\x18\x01 \x01(\x0c\x12\x0e\n\x06option\x18\x02 \x01(\rB\x11\n\x0ftransactionType\"\xb8\x01\n\tVoteStats\x12\x19\n\x11multi_sig_address\x18\x01 \x01(\x0c\x12\x12\n\nshared_key\x18\x02 \x01(\x0c\x12\x13\n\x0bsignatories\x18\x03 \x03(\x0c\x12\x11\n\ttx_hashes\x18\x04 \x03(\x0c\x12\x0f\n\x07unvotes\x18\x05 \x03(\x08\x12\x1b\n\x13\x65xpiry_block_number\x18\x06 \x01(\x04\x12\x14\n\x0ctotal_weight\x18\x07 \x01(\x04\x12\x10\n\x08\x65xecuted\x18\x08 \x01(\x08\"\xb7\x01\n\x11ProposalVoteStats\x12\x11\n\taddr_from\x18\x01 \x01(\x0c\x12\x12\n\nshared_key\x18\x02 \x01(\x0c\x12\x15\n\rproposal_type\x18\x03 \x01(\t\x12\x18\n\x10weight_by_option\x18\x04 \x03(\x04\x12\x1b\n\x13\x65xpiry_block_number\x18\x05 \x01(\x04\x12\x10\n\x08\x65xecuted\x18\x06 \x01(\x08\x12\x1b\n\x13number_of_tx_hashes\x18\x07 \x01(\x04\"-\n\x0eProposalRecord\x12\x1b\n\x13number_of_tx_hashes\x18\x01 \x01(\x04\"!\n\tTokenList\x12\x14\n\x0ctoken_txhash\x18\x01 \x03(\x0c\"R\n\x0cTokenBalance\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\x04\x12\x10\n\x08\x64\x65\x63imals\x18\x02 \x01(\x04\x12\x0f\n\x07tx_hash\x18\x03 \x01(\x0c\x12\x0e\n\x06\x64\x65lete\x18\x04 \x01(\x08\"E\n\rSlaveMetadata\x12\x13\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\x04\x12\x0f\n\x07tx_hash\x18\x02 \x01(\x0c\x12\x0e\n\x06\x64\x65lete\x18\x03 \x01(\x08\"E\n\x11LatticePKMetadata\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07tx_hash\x18\x02 \x01(\x0c\x12\x0e\n\x06\x64\x65lete\x18\x03 \x01(\x08\"G\n\rTokenMetadata\x12\x14\n\x0ctoken_txhash\x18\x01 \x01(\x0c\x12 \n\x18transfer_token_tx_hashes\x18\x02 \x03(\x0c\"\xc4\x01\n\x19\x45ncryptedEphemeralMessage\x12\x0e\n\x06msg_id\x18\x01 \x01(\x0c\x12\x0b\n\x03ttl\x18\x02 \x01(\x04\x12\x0b\n\x03ttr\x18\x03 \x01(\x04\x12\x37\n\x07\x63hannel\x18\x05 \x01(\x0b\x32&.qrl.EncryptedEphemeralMessage.Channel\x12\r\n\x05nonce\x18\x06 \x01(\x04\x12\x0f\n\x07payload\x18\x07 \x01(\x0c\x1a$\n\x07\x43hannel\x12\x19\n\x11\x65nc_aes256_symkey\x18\x04 \x01(\x0c\" \n\x0b\x41\x64\x64ressList\x12\x11\n\taddresses\x18\x01 \x03(\x0c\"`\n\x0f\x42lockHeightData\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x18\n\x10\x62lock_headerhash\x18\x02 \x01(\x0c\x12\x1d\n\x15\x63umulative_difficulty\x18\x03 \x01(\x0c\"\x81\x01\n\rBlockMetaData\x12\x18\n\x10\x62lock_difficulty\x18\x01 \x01(\x0c\x12\x1d\n\x15\x63umulative_difficulty\x18\x02 \x01(\x0c\x12\x1a\n\x12\x63hild_headerhashes\x18\x03 \x03(\x0c\x12\x1b\n\x13last_N_headerhashes\x18\x04 \x03(\x0c\"A\n\x12\x42lockNumberMapping\x12\x12\n\nheaderhash\x18\x01 \x01(\x0c\x12\x17\n\x0fprev_headerhash\x18\x02 \x01(\x0c\"X\n\x08PeerStat\x12\x0f\n\x07peer_ip\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\r\x12-\n\x10node_chain_state\x18\x03 \x01(\x0b\x32\x13.qrl.NodeChainState\"~\n\x0eNodeChainState\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x13\n\x0bheader_hash\x18\x02 \x01(\x0c\x12\x1d\n\x15\x63umulative_difficulty\x18\x03 \x01(\x0c\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x04\"<\n\x0eNodeHeaderHash\x12\x14\n\x0c\x62lock_number\x18\x01 \x01(\x04\x12\x14\n\x0cheaderhashes\x18\x02 \x03(\x0c\"-\n\x12P2PAcknowledgement\x12\x17\n\x0f\x62ytes_processed\x18\x01 \x01(\r\"|\n\x08PeerInfo\x12\x0f\n\x07peer_ip\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x18\n\x10\x62\x61nned_timestamp\x18\x03 \x01(\r\x12\x13\n\x0b\x63redibility\x18\x04 \x01(\r\x12\"\n\x1alast_connections_timestamp\x18\x05 \x03(\r\".\n\x05Peers\x12%\n\x0epeer_info_list\x18\x01 \x03(\x0b\x32\r.qrl.PeerInfo\"\xbb\x0c\n\tDevConfig\x12\x16\n\x0eprev_state_key\x18\x01 \x01(\x0c\x12\x19\n\x11\x63urrent_state_key\x18\x02 \x01(\x0c\x12\x1e\n\x16\x61\x63tivation_header_hash\x18\x03 \x01(\x0c\x12\x1f\n\x17\x61\x63tivation_block_number\x18\x04 \x01(\x04\x12#\n\x05\x63hain\x18\x05 \x01(\x0b\x32\x14.qrl.DevConfig.Chain\x12#\n\x05\x62lock\x18\x06 \x01(\x0b\x32\x14.qrl.DevConfig.Block\x12/\n\x0btransaction\x18\x07 \x01(\x0b\x32\x1a.qrl.DevConfig.Transaction\x12\x1f\n\x03pow\x18\x08 \x01(\x0b\x32\x12.qrl.DevConfig.POW\x1a\x63\n\x05\x43hain\x12\x13\n\x0breorg_limit\x18\x01 \x01(\x04\x12\x17\n\x0fmax_coin_supply\x18\x02 \x01(\x04\x12,\n$complete_emission_time_span_in_years\x18\x03 \x01(\x04\x1a\xc6\x02\n\x05\x42lock\x12\x1b\n\x13mining_nonce_offset\x18\x01 \x01(\x04\x12\x1a\n\x12\x65xtra_nonce_offset\x18\x02 \x01(\x04\x12!\n\x19mining_blob_size_in_bytes\x18\x03 \x01(\x04\x12\x1f\n\x17\x62lock_timing_in_seconds\x18\x04 \x01(\x04\x12G\n\x15\x62lock_size_controller\x18\x05 \x01(\x0b\x32(.qrl.DevConfig.Block.BlockSizeController\x1aw\n\x13\x42lockSizeController\x12 \n\x18number_of_blocks_analyze\x18\x01 \x01(\x04\x12\x17\n\x0fsize_multiplier\x18\x02 \x01(\x04\x12%\n\x1d\x62lock_min_size_limit_in_bytes\x18\x03 \x01(\x04\x1a\xc5\x06\n\x0bTransaction\x12\x1a\n\x12multi_output_limit\x18\x01 \x01(\x04\x12\x33\n\x07message\x18\x02 \x01(\x0b\x32\".qrl.DevConfig.Transaction.Message\x12/\n\x05slave\x18\x03 \x01(\x0b\x32 .qrl.DevConfig.Transaction.Slave\x12/\n\x05token\x18\x04 \x01(\x0b\x32 .qrl.DevConfig.Transaction.Token\x12\x33\n\x07lattice\x18\x05 \x01(\x0b\x32\".qrl.DevConfig.Transaction.Lattice\x12K\n\x14\x66oundation_multi_sig\x18\x06 \x01(\x0b\x32-.qrl.DevConfig.Transaction.FoundationMultiSig\x12\x35\n\x08proposal\x18\x07 \x01(\x0b\x32#.qrl.DevConfig.Transaction.Proposal\x1a\x1d\n\x07Message\x12\x12\n\nmax_length\x18\x01 \x01(\x04\x1a$\n\x05Slave\x12\x1b\n\x13slave_pk_max_length\x18\x02 \x01(\x04\x1a;\n\x05Token\x12\x19\n\x11symbol_max_length\x18\x01 \x01(\x04\x12\x17\n\x0fname_max_length\x18\x02 \x01(\x04\x1aQ\n\x07Lattice\x12\x16\n\x0epk1_max_length\x18\x01 \x01(\x04\x12\x16\n\x0epk2_max_length\x18\x02 \x01(\x04\x12\x16\n\x0epk3_max_length\x18\x03 \x01(\x04\x1a\x32\n\x12\x46oundationMultiSig\x12\x1c\n\x14threshold_percentage\x18\x01 \x01(\x04\x1a\xc0\x01\n\x08Proposal\x12\x15\n\rthreshold_per\x18\x01 \x01(\x04\x12\x17\n\x0f\x64\x65\x66\x61ult_options\x18\x02 \x03(\t\x12\x1e\n\x16\x64\x65scription_max_length\x18\x03 \x01(\x04\x12\x1a\n\x12options_max_number\x18\x04 \x01(\x04\x12\x1e\n\x16option_max_text_length\x18\x05 \x01(\x04\x12(\n proposal_config_activation_delay\x18\x06 \x01(\x04\x1a(\n\x03POW\x12\x15\n\rN_measurement\x18\x01 \x01(\x04\x12\n\n\x02kp\x18\x02 \x01(\x04\x32\xf1\x1e\n\tPublicAPI\x12P\n\x0cGetNodeState\x12\x14.qrl.GetNodeStateReq\x1a\x15.qrl.GetNodeStateResp\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/node-state\x12T\n\rGetKnownPeers\x12\x15.qrl.GetKnownPeersReq\x1a\x16.qrl.GetKnownPeersResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/known-peers\x12P\n\x0cGetPeersStat\x12\x14.qrl.GetPeersStatReq\x1a\x15.qrl.GetPeersStatResp\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/peers-stat\x12?\n\x08GetStats\x12\x10.qrl.GetStatsReq\x1a\x11.qrl.GetStatsResp\"\x0e\x82\xd3\xe4\x93\x02\x08\x12\x06/stats\x12\\\n\x0fGetAddressState\x12\x17.qrl.GetAddressStateReq\x1a\x18.qrl.GetAddressStateResp\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/address-state\x12x\n\x18GetOptimizedAddressState\x12\x17.qrl.GetAddressStateReq\x1a!.qrl.GetOptimizedAddressStateResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/optimized-address-state\x12~\n\x17GetMultiSigAddressState\x12\x1f.qrl.GetMultiSigAddressStateReq\x1a .qrl.GetMultiSigAddressStateResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/multi-sig-address-state\x12?\n\x07IsSlave\x12\x0f.qrl.IsSlaveReq\x1a\x10.qrl.IsSlaveResp\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/is-slave\x12\x43\n\tGetObject\x12\x11.qrl.GetObjectReq\x1a\x12.qrl.GetObjectResp\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/object\x12T\n\rGetLatestData\x12\x15.qrl.GetLatestDataReq\x1a\x16.qrl.GetLatestDataResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/latest-data\x12_\n\x0fPushTransaction\x12\x17.qrl.PushTransactionReq\x1a\x18.qrl.PushTransactionResp\"\x19\x82\xd3\xe4\x93\x02\x13\"\x11/push-transaction\x12W\n\rTransferCoins\x12\x15.qrl.TransferCoinsReq\x1a\x16.qrl.TransferCoinsResp\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0f/transfer-coins\x12S\n\x0cParseAddress\x12\x14.qrl.ParseAddressReq\x1a\x15.qrl.ParseAddressResp\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/parse-address\x12T\n\rGetChainStats\x12\x15.qrl.GetChainStatsReq\x1a\x16.qrl.GetChainStatsResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/chain-stats\x12\\\n\x0fGetStakingStats\x12\x17.qrl.GetStakingStatsReq\x1a\x18.qrl.GetStakingStatsResp\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/staking-stats\x12T\n\rGetStakerList\x12\x15.qrl.GetStakerListReq\x1a\x16.qrl.GetStakerListResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/staker-list\x12\x61\n\x10GetAddressFromPK\x12\x18.qrl.GetAddressFromPKReq\x1a\x19.qrl.GetAddressFromPKResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/address-from-pk\x12h\n\x14GetMultiSigCreateTxn\x12\x19.qrl.MultiSigCreateTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/multi-sig-create-txn\x12\x65\n\x13GetMultiSigSpendTxn\x12\x18.qrl.MultiSigSpendTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x14/multi-sig-spend-txn\x12\x62\n\x12GetMultiSigVoteTxn\x12\x17.qrl.MultiSigVoteTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/multi-sig-vote-txn\x12Q\n\rGetMessageTxn\x12\x12.qrl.MessageTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/message-txn\x12K\n\x0bGetTokenTxn\x12\x10.qrl.TokenTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x12\x82\xd3\xe4\x93\x02\x0c\"\n/token-txn\x12\x64\n\x13GetTransferTokenTxn\x12\x18.qrl.TransferTokenTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/transfer-token-txn\x12K\n\x0bGetSlaveTxn\x12\x10.qrl.SlaveTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x12\x82\xd3\xe4\x93\x02\x0c\"\n/slave-txn\x12Q\n\rGetLatticeTxn\x12\x12.qrl.LatticeTxnReq\x1a\x16.qrl.TransferCoinsResp\"\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/lattice-txn\x12W\n\x0eGetTransaction\x12\x16.qrl.GetTransactionReq\x1a\x17.qrl.GetTransactionResp\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/transaction\x12\x91\x01\n\x1cGetMiniTransactionsByAddress\x12$.qrl.GetMiniTransactionsByAddressReq\x1a%.qrl.GetMiniTransactionsByAddressResp\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/mini-transaction-by-address\x12\x81\x01\n\x18GetTransactionsByAddress\x12 .qrl.GetTransactionsByAddressReq\x1a!.qrl.GetTransactionsByAddressResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/transactions-by-address\x12o\n\x12GetTokensByAddress\x12 .qrl.GetTransactionsByAddressReq\x1a\x1b.qrl.GetTokensByAddressResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/tokens-by-address\x12o\n\x12GetSlavesByAddress\x12 .qrl.GetTransactionsByAddressReq\x1a\x1b.qrl.GetSlavesByAddressResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/slaves-by-address\x12|\n\x16GetLatticePKsByAddress\x12 .qrl.GetTransactionsByAddressReq\x1a\x1f.qrl.GetLatticePKsByAddressResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/lattice-pks-by-address\x12\x92\x01\n\x1dGetMultiSigAddressesByAddress\x12 .qrl.GetTransactionsByAddressReq\x1a&.qrl.GetMultiSigAddressesByAddressResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/multi-sig-addresses-by-address\x12\x94\x01\n\x1cGetMultiSigSpendTxsByAddress\x12$.qrl.GetMultiSigSpendTxsByAddressReq\x1a%.qrl.GetMultiSigSpendTxsByAddressResp\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/multi-sig-spend-txs-by-address\x12P\n\x0cGetVoteStats\x12\x14.qrl.GetVoteStatsReq\x1a\x15.qrl.GetVoteStatsResp\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/vote-stats\x12\x85\x01\n\x19GetInboxMessagesByAddress\x12 .qrl.GetTransactionsByAddressReq\x1a\".qrl.GetInboxMessagesByAddressResp\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/inbox-messages-by-address\x12G\n\nGetBalance\x12\x12.qrl.GetBalanceReq\x1a\x13.qrl.GetBalanceResp\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/balance\x12\\\n\x0fGetTotalBalance\x12\x17.qrl.GetTotalBalanceReq\x1a\x18.qrl.GetTotalBalanceResp\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/total-balance\x12\x37\n\x06GetOTS\x12\x0e.qrl.GetOTSReq\x1a\x0f.qrl.GetOTSResp\"\x0c\x82\xd3\xe4\x93\x02\x06\x12\x04/ots\x12\x43\n\tGetHeight\x12\x11.qrl.GetHeightReq\x1a\x12.qrl.GetHeightResp\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/height\x12?\n\x08GetBlock\x12\x10.qrl.GetBlockReq\x1a\x11.qrl.GetBlockResp\"\x0e\x82\xd3\xe4\x93\x02\x08\x12\x06/block\x12\x61\n\x10GetBlockByNumber\x12\x18.qrl.GetBlockByNumberReq\x1a\x19.qrl.GetBlockByNumberResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/block-by-number2\n\n\x08\x41\x64minAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qbit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADDRESSSTATE_TOKENSENTRY']._loaded_options = None
  _globals['_ADDRESSSTATE_TOKENSENTRY']._serialized_options = b'8\001'
  _globals['_ADDRESSSTATE_SLAVEPKSACCESSTYPEENTRY']._loaded_options = None
  _globals['_ADDRESSSTATE_SLAVEPKSACCESSTYPEENTRY']._serialized_options = b'8\001'
  _globals['_TRANSACTIONCOUNT_COUNTENTRY']._loaded_options = None
  _globals['_TRANSACTIONCOUNT_COUNTENTRY']._serialized_options = b'8\001'
  _globals['_PUBLICAPI'].methods_by_name['GetNodeState']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetNodeState']._serialized_options = b'\202\323\344\223\002\r\022\013/node-state'
  _globals['_PUBLICAPI'].methods_by_name['GetKnownPeers']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetKnownPeers']._serialized_options = b'\202\323\344\223\002\016\022\014/known-peers'
  _globals['_PUBLICAPI'].methods_by_name['GetPeersStat']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetPeersStat']._serialized_options = b'\202\323\344\223\002\r\022\013/peers-stat'
  _globals['_PUBLICAPI'].methods_by_name['GetStats']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetStats']._serialized_options = b'\202\323\344\223\002\010\022\006/stats'
  _globals['_PUBLICAPI'].methods_by_name['GetAddressState']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetAddressState']._serialized_options = b'\202\323\344\223\002\020\022\016/address-state'
  _globals['_PUBLICAPI'].methods_by_name['GetOptimizedAddressState']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetOptimizedAddressState']._serialized_options = b'\202\323\344\223\002\032\022\030/optimized-address-state'
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigAddressState']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigAddressState']._serialized_options = b'\202\323\344\223\002\032\022\030/multi-sig-address-state'
  _globals['_PUBLICAPI'].methods_by_name['IsSlave']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['IsSlave']._serialized_options = b'\202\323\344\223\002\013\022\t/is-slave'
  _globals['_PUBLICAPI'].methods_by_name['GetObject']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetObject']._serialized_options = b'\202\323\344\223\002\t\022\007/object'
  _globals['_PUBLICAPI'].methods_by_name['GetLatestData']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetLatestData']._serialized_options = b'\202\323\344\223\002\016\022\014/latest-data'
  _globals['_PUBLICAPI'].methods_by_name['PushTransaction']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['PushTransaction']._serialized_options = b'\202\323\344\223\002\023\"\021/push-transaction'
  _globals['_PUBLICAPI'].methods_by_name['TransferCoins']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['TransferCoins']._serialized_options = b'\202\323\344\223\002\021\"\017/transfer-coins'
  _globals['_PUBLICAPI'].methods_by_name['ParseAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['ParseAddress']._serialized_options = b'\202\323\344\223\002\020\022\016/parse-address'
  _globals['_PUBLICAPI'].methods_by_name['GetChainStats']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetChainStats']._serialized_options = b'\202\323\344\223\002\016\022\014/chain-stats'
  _globals['_PUBLICAPI'].methods_by_name['GetStakingStats']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetStakingStats']._serialized_options = b'\202\323\344\223\002\020\022\016/staking-stats'
  _globals['_PUBLICAPI'].methods_by_name['GetStakerList']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetStakerList']._serialized_options = b'\202\323\344\223\002\016\022\014/staker-list'
  _globals['_PUBLICAPI'].methods_by_name['GetAddressFromPK']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetAddressFromPK']._serialized_options = b'\202\323\344\223\002\022\022\020/address-from-pk'
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigCreateTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigCreateTxn']._serialized_options = b'\202\323\344\223\002\027\"\025/multi-sig-create-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigSpendTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigSpendTxn']._serialized_options = b'\202\323\344\223\002\026\"\024/multi-sig-spend-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigVoteTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigVoteTxn']._serialized_options = b'\202\323\344\223\002\025\"\023/multi-sig-vote-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetMessageTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMessageTxn']._serialized_options = b'\202\323\344\223\002\016\"\014/message-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetTokenTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetTokenTxn']._serialized_options = b'\202\323\344\223\002\014\"\n/token-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetTransferTokenTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetTransferTokenTxn']._serialized_options = b'\202\323\344\223\002\025\"\023/transfer-token-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetSlaveTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetSlaveTxn']._serialized_options = b'\202\323\344\223\002\014\"\n/slave-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetLatticeTxn']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetLatticeTxn']._serialized_options = b'\202\323\344\223\002\016\"\014/lattice-txn'
  _globals['_PUBLICAPI'].methods_by_name['GetTransaction']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetTransaction']._serialized_options = b'\202\323\344\223\002\016\022\014/transaction'
  _globals['_PUBLICAPI'].methods_by_name['GetMiniTransactionsByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMiniTransactionsByAddress']._serialized_options = b'\202\323\344\223\002\036\022\034/mini-transaction-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetTransactionsByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetTransactionsByAddress']._serialized_options = b'\202\323\344\223\002\032\022\030/transactions-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetTokensByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetTokensByAddress']._serialized_options = b'\202\323\344\223\002\024\022\022/tokens-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetSlavesByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetSlavesByAddress']._serialized_options = b'\202\323\344\223\002\024\022\022/slaves-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetLatticePKsByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetLatticePKsByAddress']._serialized_options = b'\202\323\344\223\002\031\022\027/lattice-pks-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigAddressesByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigAddressesByAddress']._serialized_options = b'\202\323\344\223\002!\022\037/multi-sig-addresses-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigSpendTxsByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetMultiSigSpendTxsByAddress']._serialized_options = b'\202\323\344\223\002!\022\037/multi-sig-spend-txs-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetVoteStats']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetVoteStats']._serialized_options = b'\202\323\344\223\002\r\022\013/vote-stats'
  _globals['_PUBLICAPI'].methods_by_name['GetInboxMessagesByAddress']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetInboxMessagesByAddress']._serialized_options = b'\202\323\344\223\002\034\022\032/inbox-messages-by-address'
  _globals['_PUBLICAPI'].methods_by_name['GetBalance']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetBalance']._serialized_options = b'\202\323\344\223\002\n\022\010/balance'
  _globals['_PUBLICAPI'].methods_by_name['GetTotalBalance']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetTotalBalance']._serialized_options = b'\202\323\344\223\002\020\022\016/total-balance'
  _globals['_PUBLICAPI'].methods_by_name['GetOTS']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetOTS']._serialized_options = b'\202\323\344\223\002\006\022\004/ots'
  _globals['_PUBLICAPI'].methods_by_name['GetHeight']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetHeight']._serialized_options = b'\202\323\344\223\002\t\022\007/height'
  _globals['_PUBLICAPI'].methods_by_name['GetBlock']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetBlock']._serialized_options = b'\202\323\344\223\002\010\022\006/block'
  _globals['_PUBLICAPI'].methods_by_name['GetBlockByNumber']._loaded_options = None
  _globals['_PUBLICAPI'].methods_by_name['GetBlockByNumber']._serialized_options = b'\202\323\344\223\002\022\022\020/block-by-number'
  _globals['_EMPTY']._serialized_start=49
  _globals['_EMPTY']._serialized_end=56
  _globals['_GETNODESTATEREQ']._serialized_start=58
  _globals['_GETNODESTATEREQ']._serialized_end=75
  _globals['_GETNODESTATERESP']._serialized_start=77
  _globals['_GETNODESTATERESP']._serialized_end=124
  _globals['_GETKNOWNPEERSREQ']._serialized_start=126
  _globals['_GETKNOWNPEERSREQ']._serialized_end=144
  _globals['_GETKNOWNPEERSRESP']._serialized_start=146
  _globals['_GETKNOWNPEERSRESP']._serialized_end=231
  _globals['_GETPEERSSTATREQ']._serialized_start=233
  _globals['_GETPEERSSTATREQ']._serialized_end=250
  _globals['_GETPEERSSTATRESP']._serialized_start=252
  _globals['_GETPEERSSTATRESP']._serialized_end=305
  _globals['_GETCHAINSTATSREQ']._serialized_start=307
  _globals['_GETCHAINSTATSREQ']._serialized_end=325
  _globals['_GETCHAINSTATSRESP']._serialized_start=327
  _globals['_GETCHAINSTATSRESP']._serialized_end=412
  _globals['_GETSTAKINGSTATSREQ']._serialized_start=414
  _globals['_GETSTAKINGSTATSREQ']._serialized_end=434
  _globals['_GETSTAKINGSTATSRESP']._serialized_start=437
  _globals['_GETSTAKINGSTATSRESP']._serialized_end=662
  _globals['_GETSTAKERLISTREQ']._serialized_start=664
  _globals['_GETSTAKERLISTREQ']._serialized_end=682
  _globals['_STAKERINFO']._serialized_start=684
  _globals['_STAKERINFO']._serialized_end=764
  _globals['_GETSTAKERLISTRESP']._serialized_start=766
  _globals['_GETSTAKERLISTRESP']._serialized_end=862
  _globals['_GETSTATSREQ']._serialized_start=864
  _globals['_GETSTATSREQ']._serialized_end=905
  _globals['_GETSTATSRESP']._serialized_start=908
  _globals['_GETSTATSRESP']._serialized_end=1168
  _globals['_GETADDRESSFROMPKREQ']._serialized_start=1170
  _globals['_GETADDRESSFROMPKREQ']._serialized_end=1203
  _globals['_GETADDRESSFROMPKRESP']._serialized_start=1205
  _globals['_GETADDRESSFROMPKRESP']._serialized_end=1244
  _globals['_BLOCKDATAPOINT']._serialized_start=1247
  _globals['_BLOCKDATAPOINT']._serialized_end=1425
  _globals['_GETADDRESSSTATEREQ']._serialized_start=1427
  _globals['_GETADDRESSSTATEREQ']._serialized_end=1530
  _globals['_GETADDRESSSTATERESP']._serialized_start=1532
  _globals['_GETADDRESSSTATERESP']._serialized_end=1587
  _globals['_GETOPTIMIZEDADDRESSSTATERESP']._serialized_start=1589
  _globals['_GETOPTIMIZEDADDRESSSTATERESP']._serialized_end=1662
  _globals['_GETMULTISIGADDRESSSTATEREQ']._serialized_start=1664
  _globals['_GETMULTISIGADDRESSSTATEREQ']._serialized_end=1709
  _globals['_GETMULTISIGADDRESSSTATERESP']._serialized_start=1711
  _globals['_GETMULTISIGADDRESSSTATERESP']._serialized_end=1782
  _globals['_ISSLAVEREQ']._serialized_start=1784
  _globals['_ISSLAVEREQ']._serialized_end=1838
  _globals['_ISSLAVERESP']._serialized_start=1840
  _globals['_ISSLAVERESP']._serialized_end=1869
  _globals['_PARSEADDRESSREQ']._serialized_start=1871
  _globals['_PARSEADDRESSREQ']._serialized_end=1905
  _globals['_PARSEADDRESSRESP']._serialized_start=1907
  _globals['_PARSEADDRESSRESP']._serialized_end=1981
  _globals['_GETOBJECTREQ']._serialized_start=1983
  _globals['_GETOBJECTREQ']._serialized_end=2012
  _globals['_GETOBJECTRESP']._serialized_start=2015
  _globals['_GETOBJECTRESP']._serialized_end=2203
  _globals['_GETLATESTDATAREQ']._serialized_start=2206
  _globals['_GETLATESTDATAREQ']._serialized_end=2389
  _globals['_GETLATESTDATAREQ_FILTER']._serialized_start=2306
  _globals['_GETLATESTDATAREQ_FILTER']._serialized_end=2389
  _globals['_GETLATESTDATARESP']._serialized_start=2392
  _globals['_GETLATESTDATARESP']._serialized_end=2567
  _globals['_TRANSFERCOINSREQ']._serialized_start=2570
  _globals['_TRANSFERCOINSREQ']._serialized_end=2700
  _globals['_TRANSFERCOINSRESP']._serialized_start=2702
  _globals['_TRANSFERCOINSRESP']._serialized_end=2786
  _globals['_PUSHTRANSACTIONREQ']._serialized_start=2788
  _globals['_PUSHTRANSACTIONREQ']._serialized_end=2854
  _globals['_PUSHTRANSACTIONRESP']._serialized_start=2857
  _globals['_PUSHTRANSACTIONRESP']._serialized_end=3059
  _globals['_PUSHTRANSACTIONRESP_RESPONSECODE']._serialized_start=2983
  _globals['_PUSHTRANSACTIONRESP_RESPONSECODE']._serialized_end=3059
  _globals['_MULTISIGCREATETXNREQ']._serialized_start=3062
  _globals['_MULTISIGCREATETXNREQ']._serialized_end=3192
  _globals['_MULTISIGSPENDTXNREQ']._serialized_start=3195
  _globals['_MULTISIGSPENDTXNREQ']._serialized_end=3358
  _globals['_MULTISIGVOTETXNREQ']._serialized_start=3360
  _globals['_MULTISIGVOTETXNREQ']._serialized_end=3467
  _globals['_MESSAGETXNREQ']._serialized_start=3469
  _globals['_MESSAGETXNREQ']._serialized_end=3569
  _globals['_TOKENTXNREQ']._serialized_start=3572
  _globals['_TOKENTXNREQ']._serialized_end=3745
  _globals['_TRANSFERTOKENTXNREQ']._serialized_start=3748
  _globals['_TRANSFERTOKENTXNREQ']._serialized_end=3881
  _globals['_SLAVETXNREQ']._serialized_start=3883
  _globals['_SLAVETXNREQ']._serialized_end=3988
  _globals['_LATTICETXNREQ']._serialized_start=3990
  _globals['_LATTICETXNREQ']._serialized_end=4095
  _globals['_MINITRANSACTION']._serialized_start=4097
  _globals['_MINITRANSACTION']._serialized_end=4169
  _globals['_GETTRANSACTIONREQ']._serialized_start=4171
  _globals['_GETTRANSACTIONREQ']._serialized_end=4207
  _globals['_GETTRANSACTIONRESP']._serialized_start=4210
  _globals['_GETTRANSACTIONRESP']._serialized_end=4370
  _globals['_GETMINITRANSACTIONSBYADDRESSREQ']._serialized_start=4372
  _globals['_GETMINITRANSACTIONSBYADDRESSREQ']._serialized_end=4466
  _globals['_GETMINITRANSACTIONSBYADDRESSRESP']._serialized_start=4468
  _globals['_GETMINITRANSACTIONSBYADDRESSRESP']._serialized_end=4568
  _globals['_GETTRANSACTIONSBYADDRESSREQ']._serialized_start=4570
  _globals['_GETTRANSACTIONSBYADDRESSREQ']._serialized_end=4660
  _globals['_GETTRANSACTIONSBYADDRESSRESP']._serialized_start=4662
  _globals['_GETTRANSACTIONSBYADDRESSRESP']._serialized_end=4746
  _globals['_GETMULTISIGSPENDTXSBYADDRESSREQ']._serialized_start=4749
  _globals['_GETMULTISIGSPENDTXSBYADDRESSREQ']._serialized_end=5061
  _globals['_GETMULTISIGSPENDTXSBYADDRESSREQ_FILTERTYPE']._serialized_start=4916
  _globals['_GETMULTISIGSPENDTXSBYADDRESSREQ_FILTERTYPE']._serialized_end=5061
  _globals['_GETMULTISIGSPENDTXSBYADDRESSRESP']._serialized_start=5063
  _globals['_GETMULTISIGSPENDTXSBYADDRESSRESP']._serialized_end=5151
  _globals['_GETVOTESTATSREQ']._serialized_start=5153
  _globals['_GETVOTESTATSREQ']._serialized_end=5203
  _globals['_GETVOTESTATSRESP']._serialized_start=5205
  _globals['_GETVOTESTATSRESP']._serialized_end=5259
  _globals['_GETINBOXMESSAGESBYADDRESSRESP']._serialized_start=5261
  _globals['_GETINBOXMESSAGESBYADDRESSRESP']._serialized_end=5346
  _globals['_INBOXMESSAGE']._serialized_start=5348
  _globals['_INBOXMESSAGE']._serialized_end=5456
  _globals['_TOKENDETAIL']._serialized_start=5458
  _globals['_TOKENDETAIL']._serialized_end=5540
  _globals['_GETTOKENSBYADDRESSRESP']._serialized_start=5542
  _globals['_GETTOKENSBYADDRESSRESP']._serialized_end=5607
  _globals['_SLAVEDETAIL']._serialized_start=5609
  _globals['_SLAVEDETAIL']._serialized_end=5666
  _globals['_GETSLAVESBYADDRESSRESP']._serialized_start=5668
  _globals['_GETSLAVESBYADDRESSRESP']._serialized_end=5733
  _globals['_LATTICEPKSDETAIL']._serialized_start=5735
  _globals['_LATTICEPKSDETAIL']._serialized_end=5809
  _globals['_GETLATTICEPKSBYADDRESSRESP']._serialized_start=5811
  _globals['_GETLATTICEPKSBYADDRESSRESP']._serialized_end=5890
  _globals['_MULTISIGDETAIL']._serialized_start=5892
  _globals['_MULTISIGDETAIL']._serialized_end=5942
  _globals['_GETMULTISIGADDRESSESBYADDRESSRESP']._serialized_start=5944
  _globals['_GETMULTISIGADDRESSESBYADDRESSRESP']._serialized_end=6026
  _globals['_GETBALANCEREQ']._serialized_start=6028
  _globals['_GETBALANCEREQ']._serialized_end=6060
  _globals['_GETBALANCERESP']._serialized_start=6062
  _globals['_GETBALANCERESP']._serialized_end=6095
  _globals['_GETTOTALBALANCEREQ']._serialized_start=6097
  _globals['_GETTOTALBALANCEREQ']._serialized_end=6136
  _globals['_GETTOTALBALANCERESP']._serialized_start=6138
  _globals['_GETTOTALBALANCERESP']._serialized_end=6176
  _globals['_GETOTSREQ']._serialized_start=6178
  _globals['_GETOTSREQ']._serialized_end=6276
  _globals['_OTSBITFIELDBYPAGE']._serialized_start=6278
  _globals['_OTSBITFIELDBYPAGE']._serialized_end=6340
  _globals['_GETOTSRESP']._serialized_start=6343
  _globals['_GETOTSRESP']._serialized_end=6472
  _globals['_GETHEIGHTREQ']._serialized_start=6474
  _globals['_GETHEIGHTREQ']._serialized_end=6488
  _globals['_GETHEIGHTRESP']._serialized_start=6490
  _globals['_GETHEIGHTRESP']._serialized_end=6521
  _globals['_GETBLOCKREQ']._serialized_start=6523
  _globals['_GETBLOCKREQ']._serialized_end=6557
  _globals['_GETBLOCKRESP']._serialized_start=6559
  _globals['_GETBLOCKRESP']._serialized_end=6600
  _globals['_GETBLOCKBYNUMBERREQ']._serialized_start=6602
  _globals['_GETBLOCKBYNUMBERREQ']._serialized_end=6645
  _globals['_GETBLOCKBYNUMBERRESP']._serialized_start=6647
  _globals['_GETBLOCKBYNUMBERRESP']._serialized_end=6696
  _globals['_GETLOCALADDRESSESREQ']._serialized_start=6698
  _globals['_GETLOCALADDRESSESREQ']._serialized_end=6720
  _globals['_GETLOCALADDRESSESRESP']._serialized_start=6722
  _globals['_GETLOCALADDRESSESRESP']._serialized_end=6764
  _globals['_NODEINFO']._serialized_start=6767
  _globals['_NODEINFO']._serialized_end=7036
  _globals['_NODEINFO_STATE']._serialized_start=6965
  _globals['_NODEINFO_STATE']._serialized_end=7036
  _globals['_ADDRESSDESCRIPTOR']._serialized_start=7039
  _globals['_ADDRESSDESCRIPTOR']._serialized_end=7172
  _globals['_STOREDPEERS']._serialized_start=7174
  _globals['_STOREDPEERS']._serialized_end=7213
  _globals['_PEER']._serialized_start=7215
  _globals['_PEER']._serialized_end=7233
  _globals['_ADDRESSSTATE']._serialized_start=7236
  _globals['_ADDRESSSTATE']._serialized_end=7618
  _globals['_ADDRESSSTATE_TOKENSENTRY']._serialized_start=7514
  _globals['_ADDRESSSTATE_TOKENSENTRY']._serialized_end=7559
  _globals['_ADDRESSSTATE_SLAVEPKSACCESSTYPEENTRY']._serialized_start=7561
  _globals['_ADDRESSSTATE_SLAVEPKSACCESSTYPEENTRY']._serialized_end=7618
  _globals['_OPTIMIZEDADDRESSSTATE']._serialized_start=7621
  _globals['_OPTIMIZEDADDRESSSTATE']._serialized_end=8096
  _globals['_MULTISIGADDRESSSTATE']._serialized_start=8099
  _globals['_MULTISIGADDRESSSTATE']._serialized_end=8502
  _globals['_MULTISIGADDRESSESLIST']._serialized_start=8504
  _globals['_MULTISIGADDRESSESLIST']._serialized_end=8543
  _globals['_DATALIST']._serialized_start=8545
  _globals['_DATALIST']._serialized_end=8571
  _globals['_BITFIELD']._serialized_start=8573
  _globals['_BITFIELD']._serialized_end=8602
  _globals['_TRANSACTIONHASHLIST']._serialized_start=8604
  _globals['_TRANSACTIONHASHLIST']._serialized_end=8641
  _globals['_LATTICEPK']._serialized_start=8643
  _globals['_LATTICEPK']._serialized_end=8694
  _globals['_ADDRESSAMOUNT']._serialized_start=8696
  _globals['_ADDRESSAMOUNT']._serialized_end=8744
  _globals['_BLOCKHEADER']._serialized_start=8747
  _globals['_BLOCKHEADER']._serialized_end=8962
  _globals['_BLOCKHEADEREXTENDED']._serialized_start=8964
  _globals['_BLOCKHEADEREXTENDED']._serialized_end=9069
  _globals['_TRANSACTIONCOUNT']._serialized_start=9071
  _globals['_TRANSACTIONCOUNT']._serialized_end=9184
  _globals['_TRANSACTIONCOUNT_COUNTENTRY']._serialized_start=9140
  _globals['_TRANSACTIONCOUNT_COUNTENTRY']._serialized_end=9184
  _globals['_TRANSACTIONEXTENDED']._serialized_start=9187
  _globals['_TRANSACTIONEXTENDED']._serialized_end=9332
  _globals['_BLOCKEXTENDED']._serialized_start=9335
  _globals['_BLOCKEXTENDED']._serialized_end=9501
  _globals['_BLOCK']._serialized_start=9503
  _globals['_BLOCK']._serialized_end=9630
  _globals['_GENESISBALANCE']._serialized_start=9632
  _globals['_GENESISBALANCE']._serialized_end=9682
  _globals['_BLOCKMETADATALIST']._serialized_start=9684
  _globals['_BLOCKMETADATALIST']._serialized_end=9752
  _globals['_TRANSACTION']._serialized_start=9755
  _globals['_TRANSACTION']._serialized_end=12485
  _globals['_TRANSACTION_TRANSFER']._serialized_start=10512
  _globals['_TRANSACTION_TRANSFER']._serialized_end=10579
  _globals['_TRANSACTION_COINBASE']._serialized_start=10581
  _globals['_TRANSACTION_COINBASE']._serialized_end=10624
  _globals['_TRANSACTION_LATTICEPUBLICKEY']._serialized_start=10626
  _globals['_TRANSACTION_LATTICEPUBLICKEY']._serialized_end=10683
  _globals['_TRANSACTION_MESSAGE']._serialized_start=10685
  _globals['_TRANSACTION_MESSAGE']._serialized_end=10733
  _globals['_TRANSACTION_TOKEN']._serialized_start=10735
  _globals['_TRANSACTION_TOKEN']._serialized_end=10851
  _globals['_TRANSACTION_TRANSFERTOKEN']._serialized_start=10853
  _globals['_TRANSACTION_TRANSFERTOKEN']._serialized_end=10925
  _globals['_TRANSACTION_SLAVE']._serialized_start=10927
  _globals['_TRANSACTION_SLAVE']._serialized_end=10975
  _globals['_TRANSACTION_MULTISIGCREATE']._serialized_start=10977
  _globals['_TRANSACTION_MULTISIGCREATE']._serialized_end=11050
  _globals['_TRANSACTION_MULTISIGSPEND']._serialized_start=11052
  _globals['_TRANSACTION_MULTISIGSPEND']._serialized_end=11158
  _globals['_TRANSACTION_MULTISIGVOTE']._serialized_start=11160
  _globals['_TRANSACTION_MULTISIGVOTE']._serialized_end=11232
  _globals['_TRANSACTION_PROPOSALCREATE']._serialized_start=11235
  _globals['_TRANSACTION_PROPOSALCREATE']._serialized_end=12414
  _globals['_TRANSACTION_PROPOSALCREATE_QIP']._serialized_start=11469
  _globals['_TRANSACTION_PROPOSALCREATE_QIP']._serialized_end=11492
  _globals['_TRANSACTION_PROPOSALCREATE_CONFIG']._serialized_start=11495
  _globals['_TRANSACTION_PROPOSALCREATE_CONFIG']._serialized_end=12372
  _globals['_TRANSACTION_PROPOSALCREATE_OTHER']._serialized_start=12374
  _globals['_TRANSACTION_PROPOSALCREATE_OTHER']._serialized_end=12398
  _globals['_TRANSACTION_PROPOSALVOTE']._serialized_start=12416
  _globals['_TRANSACTION_PROPOSALVOTE']._serialized_end=12466
  _globals['_VOTESTATS']._serialized_start=12488
  _globals['_VOTESTATS']._serialized_end=12672
  _globals['_PROPOSALVOTESTATS']._serialized_start=12675
  _globals['_PROPOSALVOTESTATS']._serialized_end=12858
  _globals['_PROPOSALRECORD']._serialized_start=12860
  _globals['_PROPOSALRECORD']._serialized_end=12905
  _globals['_TOKENLIST']._serialized_start=12907
  _globals['_TOKENLIST']._serialized_end=12940
  _globals['_TOKENBALANCE']._serialized_start=12942
  _globals['_TOKENBALANCE']._serialized_end=13024
  _globals['_SLAVEMETADATA']._serialized_start=13026
  _globals['_SLAVEMETADATA']._serialized_end=13095
  _globals['_LATTICEPKMETADATA']._serialized_start=13097
  _globals['_LATTICEPKMETADATA']._serialized_end=13166
  _globals['_TOKENMETADATA']._serialized_start=13168
  _globals['_TOKENMETADATA']._serialized_end=13239
  _globals['_ENCRYPTEDEPHEMERALMESSAGE']._serialized_start=13242
  _globals['_ENCRYPTEDEPHEMERALMESSAGE']._serialized_end=13438
  _globals['_ENCRYPTEDEPHEMERALMESSAGE_CHANNEL']._serialized_start=13402
  _globals['_ENCRYPTEDEPHEMERALMESSAGE_CHANNEL']._serialized_end=13438
  _globals['_ADDRESSLIST']._serialized_start=13440
  _globals['_ADDRESSLIST']._serialized_end=13472
  _globals['_BLOCKHEIGHTDATA']._serialized_start=13474
  _globals['_BLOCKHEIGHTDATA']._serialized_end=13570
  _globals['_BLOCKMETADATA']._serialized_start=13573
  _globals['_BLOCKMETADATA']._serialized_end=13702
  _globals['_BLOCKNUMBERMAPPING']._serialized_start=13704
  _globals['_BLOCKNUMBERMAPPING']._serialized_end=13769
  _globals['_PEERSTAT']._serialized_start=13771
  _globals['_PEERSTAT']._serialized_end=13859
  _globals['_NODECHAINSTATE']._serialized_start=13861
  _globals['_NODECHAINSTATE']._serialized_end=13987
  _globals['_NODEHEADERHASH']._serialized_start=13989
  _globals['_NODEHEADERHASH']._serialized_end=14049
  _globals['_P2PACKNOWLEDGEMENT']._serialized_start=14051
  _globals['_P2PACKNOWLEDGEMENT']._serialized_end=14096
  _globals['_PEERINFO']._serialized_start=14098
  _globals['_PEERINFO']._serialized_end=14222
  _globals['_PEERS']._serialized_start=14224
  _globals['_PEERS']._serialized_end=14270
  _globals['_DEVCONFIG']._serialized_start=14273
  _globals['_DEVCONFIG']._serialized_end=15868
  _globals['_DEVCONFIG_CHAIN']._serialized_start=14558
  _globals['_DEVCONFIG_CHAIN']._serialized_end=14657
  _globals['_DEVCONFIG_BLOCK']._serialized_start=14660
  _globals['_DEVCONFIG_BLOCK']._serialized_end=14986
  _globals['_DEVCONFIG_BLOCK_BLOCKSIZECONTROLLER']._serialized_start=14867
  _globals['_DEVCONFIG_BLOCK_BLOCKSIZECONTROLLER']._serialized_end=14986
  _globals['_DEVCONFIG_TRANSACTION']._serialized_start=14989
  _globals['_DEVCONFIG_TRANSACTION']._serialized_end=15826
  _globals['_DEVCONFIG_TRANSACTION_MESSAGE']._serialized_start=15368
  _globals['_DEVCONFIG_TRANSACTION_MESSAGE']._serialized_end=15397
  _globals['_DEVCONFIG_TRANSACTION_SLAVE']._serialized_start=15399
  _globals['_DEVCONFIG_TRANSACTION_SLAVE']._serialized_end=15435
  _globals['_DEVCONFIG_TRANSACTION_TOKEN']._serialized_start=15437
  _globals['_DEVCONFIG_TRANSACTION_TOKEN']._serialized_end=15496
  _globals['_DEVCONFIG_TRANSACTION_LATTICE']._serialized_start=15498
  _globals['_DEVCONFIG_TRANSACTION_LATTICE']._serialized_end=15579
  _globals['_DEVCONFIG_TRANSACTION_FOUNDATIONMULTISIG']._serialized_start=15581
  _globals['_DEVCONFIG_TRANSACTION_FOUNDATIONMULTISIG']._serialized_end=15631
  _globals['_DEVCONFIG_TRANSACTION_PROPOSAL']._serialized_start=15634
  _globals['_DEVCONFIG_TRANSACTION_PROPOSAL']._serialized_end=15826
  _globals['_DEVCONFIG_POW']._serialized_start=15828
  _globals['_DEVCONFIG_POW']._serialized_end=15868
  _globals['_PUBLICAPI']._serialized_start=15871
  _globals['_PUBLICAPI']._serialized_end=19824
  _globals['_ADMINAPI']._serialized_start=19826
  _globals['_ADMINAPI']._serialized_end=19836
# @@protoc_insertion_point(module_scope)



# coding=utf-8
# Distributed under the MIT software license, see the accompanying
# file LICENSE or http://www.opensource.org/licenses/mit-license.php.
import threading

from qbitcoin.core import config
from qbitcoin.core.Singleton import Singleton
from qbitcoin.crypto.Qryptonight7 import Qryptonight7
from qbitcoin.crypto.QRandomX import QRandomX


class Qryptonight(object, metaclass=Singleton):

    def __init__(self):
        self.lock = threading.Lock()
        self._qryptonight_7 = Qryptonight7()
        self._qrandom_x = QRandomX()

    def get_qn(self, block_number):
        if block_number < config.dev.hard_fork_heights[0]:
            return self._qryptonight_7
        else:
            return self._qrandom_x

    def get_seed_height(self, block_number):
        return self._qrandom_x.get_seed_height(block_number)

    def hash(self, block_number, seed_height, seed_hash, blob):
        with self.lock:
            if block_number < config.dev.hard_fork_heights[0]:
                return bytes(self._qryptonight_7.hash(blob))
            else:
                return bytes(self._qrandom_x.hash(block_number, seed_height, seed_hash, blob))
